==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/signalrservice/kotlin/inputs/ResourceLogConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.signalrservice.kotlin.inputs

import com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Resource log configuration of a Microsoft.SignalRService resource.
 * @property categories Gets or sets the list of category configurations.
 */
public data class ResourceLogConfigurationArgs(
    public val categories: Output<List<ResourceLogCategoryArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs =
        com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs.builder()
            .categories(
                categories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceLogConfigurationArgs].
 */
@PulumiTagMarker
public class ResourceLogConfigurationArgsBuilder internal constructor() {
    private var categories: Output<List<ResourceLogCategoryArgs>>? = null

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("vystcavjrfclyklm")
    public suspend fun categories(`value`: Output<List<ResourceLogCategoryArgs>>) {
        this.categories = value
    }

    @JvmName("vjlpbhlfrlknlxoe")
    public suspend fun categories(vararg values: Output<ResourceLogCategoryArgs>) {
        this.categories = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("mqxyofgijrlsiigc")
    public suspend fun categories(values: List<Output<ResourceLogCategoryArgs>>) {
        this.categories = Output.all(values)
    }

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("tnsvewqrnnxudsif")
    public suspend fun categories(`value`: List<ResourceLogCategoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("dgrltxxtwucrakxb")
    public suspend fun categories(argument: List<suspend ResourceLogCategoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceLogCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("ooikwpyqdynbfjjl")
    public suspend fun categories(
        vararg
        argument: suspend ResourceLogCategoryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceLogCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("aogpftpxmyuiiuxl")
    public suspend fun categories(argument: suspend ResourceLogCategoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceLogCategoryArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("qumdeyhmpslbqobd")
    public suspend fun categories(vararg values: ResourceLogCategoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    internal fun build(): ResourceLogConfigurationArgs = ResourceLogConfigurationArgs(
        categories = categories,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/signalrservice/kotlin/inputs/ResourceLogConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.signalrservice.kotlin.inputs

import com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Resource log configuration of a Microsoft.SignalRService resource.
 * @property categories Gets or sets the list of category configurations.
 */
public data class ResourceLogConfigurationArgs(
    public val categories: Output<List<ResourceLogCategoryArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs =
        com.pulumi.azurenative.signalrservice.inputs.ResourceLogConfigurationArgs.builder()
            .categories(
                categories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceLogConfigurationArgs].
 */
@PulumiTagMarker
public class ResourceLogConfigurationArgsBuilder internal constructor() {
    private var categories: Output<List<ResourceLogCategoryArgs>>? = null

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("aucyqmxhwbsktwyg")
    public suspend fun categories(`value`: Output<List<ResourceLogCategoryArgs>>) {
        this.categories = value
    }

    @JvmName("niystuuojobjladr")
    public suspend fun categories(vararg values: Output<ResourceLogCategoryArgs>) {
        this.categories = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("sykuepdadghncfam")
    public suspend fun categories(values: List<Output<ResourceLogCategoryArgs>>) {
        this.categories = Output.all(values)
    }

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("hftgtnttewbeuoft")
    public suspend fun categories(`value`: List<ResourceLogCategoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("sovjkwpqbblgnrjv")
    public suspend fun categories(argument: List<suspend ResourceLogCategoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceLogCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("wocxwohgpekpiehk")
    public suspend fun categories(
        vararg
        argument: suspend ResourceLogCategoryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceLogCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("dkpqswgcvnyncbhn")
    public suspend fun categories(argument: suspend ResourceLogCategoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceLogCategoryArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("cjbwtfvtgmjalhlq")
    public suspend fun categories(vararg values: ResourceLogCategoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    internal fun build(): ResourceLogConfigurationArgs = ResourceLogConfigurationArgs(
        categories = categories,
    )
}
